@@ -44,7 +44,7 @@ class TestInstance(object):
 
         contents = _get_file_contents('../%s/tiddlywebconfig.py' % instance_dir)
 
-        assert "'system_plugins': ['tiddlywebwiki']" in contents
+        assert "'system_plugins': ['tiddlywebwiki', 'status']" in contents
         assert "'twanager_plugins': ['tiddlywebwiki']" in contents
 
     def test_create_bag_policies(self):
